//
//  BookmarkNavigationItemTests.swift
//  FreetimeTests
//
//  Created by B_Litwin on 5/5/18.
//  Copyright © 2018 Ryan Nystrom. All rights reserved.
//

import XCTest
@testable import Freetime

class BookmarkNavigationControllerTests: XCTestCase {

    func test_bookmarkNavItemActionsWork() {

        //setup

        let issue = Bookmark(type: .issue, name: "issue 1", owner: "brian", title: "issue 1 tests")
        let other = Bookmark(type: .commit, name: "issue 2", owner: "litwin")
        let bookmarkStore = BookmarkStore(token: "")
        bookmarkStore.values = [other]

        guard let bookmarkNavigationController = BookmarkNavigationController(store: bookmarkStore, model: issue) else {
            XCTFail("bookmarkNavigationController could not be initialized")
            return
        }

        let navigationItem = BookmarkNavigationController.disabledNavigationItem
        bookmarkNavigationController.configureNavigationItem(navigationItem)

        //test initial button and model state
        XCTAssertEqual(bookmarkStore.values, [other]) //models state
        XCTAssertEqual(navigationItem.action, #selector(bookmarkNavigationController.add(sender:))) //item's initial action

        //test button tap updates model and button action
        bookmarkNavigationController.add(sender: navigationItem)
        XCTAssertEqual(navigationItem.action, #selector(bookmarkNavigationController.remove(sender:))) //item's action
        XCTAssertEqual(bookmarkStore.values, [issue, other]) //model updated

        //test button tapped again updates model and button action
        bookmarkNavigationController.remove(sender: navigationItem)
        XCTAssertEqual(navigationItem.action, #selector(bookmarkNavigationController.add(sender:))) //item's action
        XCTAssertEqual(bookmarkStore.values, [other]) //model updated

    }

}
